@@ -3,6 +3,7 @@ from typing import List, Union
 from pydantic import BaseModel
 
 from weaverbird.steps import (
+    AddMissingDatesStep,
     AggregateStep,
     AppendStep,
     ArgmaxStep,
@@ -14,6 +15,7 @@ from weaverbird.steps import (
     DeleteStep,
     DomainStep,
     DuplicateStep,
+    DurationStep,
     EvolutionStep,
     FillnaStep,
     FilterStep,
@@ -44,6 +46,7 @@ from weaverbird.steps import (
 )
 
 PipelineStep = Union[
+    AddMissingDatesStep,
     AggregateStep,
     AppendStep,
     ArgmaxStep,
@@ -55,6 +58,7 @@ PipelineStep = Union[
     DeleteStep,
     DomainStep,
     DuplicateStep,
+    DurationStep,
     EvolutionStep,
     FillnaStep,
     FilterStep,
