@@ -1,7 +1,7 @@
 from typing import Any, List
 
 from pandas import DataFrame
-from pydantic import Field
+from pydantic import Field, root_validator
 
 from weaverbird.steps import BaseStep
 from weaverbird.types import ColumnName, DomainRetriever, PipelineExecutor
@@ -12,6 +12,12 @@ class FillnaStep(BaseStep):
     columns: List[ColumnName] = Field(min_items=1)
     value: Any
 
+    @root_validator(pre=True)
+    def handle_legacy_syntax(cls, values):
+        if 'column' in values:
+            values['columns'] = [values.pop('column')]
+        return values
+
     def execute(
         self,
         df: DataFrame,
