@@ -1,7 +1,7 @@
 from pandas import DataFrame
 from pydantic import Field
 
-from weaverbird.formula import clean_formula
+from weaverbird.formula import clean_formula, eval_formula
 from weaverbird.steps.base import BaseStep
 from weaverbird.types import ColumnName
 
@@ -12,5 +12,5 @@ class FormulaStep(BaseStep):
     formula: str
 
     def execute(self, df: DataFrame, domain_retriever=None, execute_pipeline=None) -> DataFrame:
-        serie = df.eval(clean_formula(self.formula))
+        serie = eval_formula(df, clean_formula(self.formula))
         return df.assign(**{self.new_column: serie})
